@@ -33,7 +33,9 @@ __all__ = (
     "SeverityType",
     "TypeType",
     "VendorNameType",
+    "CodeGuruReviewerServiceName",
     "ServiceName",
+    "ResourceServiceName",
     "PaginatorName",
     "WaiterName",
 )
@@ -68,6 +70,7 @@ RepositoryAssociationSucceededWaiterName = Literal["repository_association_succe
 SeverityType = Literal["Critical", "High", "Info", "Low", "Medium"]
 TypeType = Literal["PullRequest", "RepositoryAnalysis"]
 VendorNameType = Literal["GitHub", "GitLab", "NativeS3"]
+CodeGuruReviewerServiceName = Literal["codeguru-reviewer"]
 ServiceName = Literal[
     "accessanalyzer",
     "account",
@@ -99,6 +102,7 @@ ServiceName = Literal[
     "backup",
     "backup-gateway",
     "batch",
+    "billingconductor",
     "braket",
     "budgets",
     "ce",
@@ -221,6 +225,7 @@ ServiceName = Literal[
     "kafka",
     "kafkaconnect",
     "kendra",
+    "keyspaces",
     "kinesis",
     "kinesis-video-archived-media",
     "kinesis-video-media",
@@ -369,5 +374,17 @@ ServiceName = Literal[
     "workspaces-web",
     "xray",
 ]
+ResourceServiceName = Literal[
+    "cloudformation",
+    "cloudwatch",
+    "dynamodb",
+    "ec2",
+    "glacier",
+    "iam",
+    "opsworks",
+    "s3",
+    "sns",
+    "sqs",
+]
 PaginatorName = Literal["list_repository_associations"]
 WaiterName = Literal["code_review_completed", "repository_association_succeeded"]
