@@ -6,14 +6,15 @@ Type annotations for codeguru-reviewer service client paginators.
 Usage::
 
     ```python
-    import boto3
+    from boto3.session import Session
 
-    from mypy_boto3_codeguru_reviewer import CodeGuruReviewerClient
+    from mypy_boto3_codeguru_reviewer.client import CodeGuruReviewerClient
     from mypy_boto3_codeguru_reviewer.paginator import (
         ListRepositoryAssociationsPaginator,
     )
 
-    client: CodeGuruReviewerClient = boto3.client("codeguru-reviewer")
+    session = Session()
+    client: CodeGuruReviewerClient = session.client("codeguru-reviewer")
 
     list_repository_associations_paginator: ListRepositoryAssociationsPaginator = client.get_paginator("list_repository_associations")
     ```
@@ -41,7 +42,7 @@ class _PageIterator(Generic[_ItemTypeDef], PageIterator):
 
 class ListRepositoryAssociationsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Paginator.ListRepositoryAssociations)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Paginator.ListRepositoryAssociations)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguru_reviewer/paginators.html#listrepositoryassociationspaginator)
     """
 
@@ -55,6 +56,6 @@ class ListRepositoryAssociationsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListRepositoryAssociationsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Paginator.ListRepositoryAssociations.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Paginator.ListRepositoryAssociations.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguru_reviewer/paginators.html#listrepositoryassociationspaginator)
         """
