@@ -15,6 +15,8 @@ import sys
 from datetime import datetime
 from typing import Dict, List, Mapping, Sequence
 
+from typing_extensions import NotRequired
+
 from .literals import (
     AnalysisTypeType,
     EncryptionOptionType,
@@ -91,29 +93,15 @@ __all__ = (
     "WaiterConfigTypeDef",
 )
 
-_RequiredAssociateRepositoryRequestRequestTypeDef = TypedDict(
-    "_RequiredAssociateRepositoryRequestRequestTypeDef",
+AssociateRepositoryRequestRequestTypeDef = TypedDict(
+    "AssociateRepositoryRequestRequestTypeDef",
     {
         "Repository": "RepositoryTypeDef",
+        "ClientRequestToken": NotRequired[str],
+        "Tags": NotRequired[Mapping[str, str]],
+        "KMSKeyDetails": NotRequired["KMSKeyDetailsTypeDef"],
     },
 )
-_OptionalAssociateRepositoryRequestRequestTypeDef = TypedDict(
-    "_OptionalAssociateRepositoryRequestRequestTypeDef",
-    {
-        "ClientRequestToken": str,
-        "Tags": Mapping[str, str],
-        "KMSKeyDetails": "KMSKeyDetailsTypeDef",
-    },
-    total=False,
-)
-
-
-class AssociateRepositoryRequestRequestTypeDef(
-    _RequiredAssociateRepositoryRequestRequestTypeDef,
-    _OptionalAssociateRepositoryRequestRequestTypeDef,
-):
-    pass
-
 
 AssociateRepositoryResponseTypeDef = TypedDict(
     "AssociateRepositoryResponseTypeDef",
@@ -132,24 +120,13 @@ BranchDiffSourceCodeTypeTypeDef = TypedDict(
     },
 )
 
-_RequiredCodeArtifactsTypeDef = TypedDict(
-    "_RequiredCodeArtifactsTypeDef",
+CodeArtifactsTypeDef = TypedDict(
+    "CodeArtifactsTypeDef",
     {
         "SourceCodeArtifactsObjectKey": str,
+        "BuildArtifactsObjectKey": NotRequired[str],
     },
 )
-_OptionalCodeArtifactsTypeDef = TypedDict(
-    "_OptionalCodeArtifactsTypeDef",
-    {
-        "BuildArtifactsObjectKey": str,
-    },
-    total=False,
-)
-
-
-class CodeArtifactsTypeDef(_RequiredCodeArtifactsTypeDef, _OptionalCodeArtifactsTypeDef):
-    pass
-
 
 CodeCommitRepositoryTypeDef = TypedDict(
     "CodeCommitRepositoryTypeDef",
@@ -161,95 +138,68 @@ CodeCommitRepositoryTypeDef = TypedDict(
 CodeReviewSummaryTypeDef = TypedDict(
     "CodeReviewSummaryTypeDef",
     {
-        "Name": str,
-        "CodeReviewArn": str,
-        "RepositoryName": str,
-        "Owner": str,
-        "ProviderType": ProviderTypeType,
-        "State": JobStateType,
-        "CreatedTimeStamp": datetime,
-        "LastUpdatedTimeStamp": datetime,
-        "Type": TypeType,
-        "PullRequestId": str,
-        "MetricsSummary": "MetricsSummaryTypeDef",
-        "SourceCodeType": "SourceCodeTypeTypeDef",
+        "Name": NotRequired[str],
+        "CodeReviewArn": NotRequired[str],
+        "RepositoryName": NotRequired[str],
+        "Owner": NotRequired[str],
+        "ProviderType": NotRequired[ProviderTypeType],
+        "State": NotRequired[JobStateType],
+        "CreatedTimeStamp": NotRequired[datetime],
+        "LastUpdatedTimeStamp": NotRequired[datetime],
+        "Type": NotRequired[TypeType],
+        "PullRequestId": NotRequired[str],
+        "MetricsSummary": NotRequired["MetricsSummaryTypeDef"],
+        "SourceCodeType": NotRequired["SourceCodeTypeTypeDef"],
     },
-    total=False,
 )
 
 CodeReviewTypeDef = TypedDict(
     "CodeReviewTypeDef",
     {
-        "Name": str,
-        "CodeReviewArn": str,
-        "RepositoryName": str,
-        "Owner": str,
-        "ProviderType": ProviderTypeType,
-        "State": JobStateType,
-        "StateReason": str,
-        "CreatedTimeStamp": datetime,
-        "LastUpdatedTimeStamp": datetime,
-        "Type": TypeType,
-        "PullRequestId": str,
-        "SourceCodeType": "SourceCodeTypeTypeDef",
-        "AssociationArn": str,
-        "Metrics": "MetricsTypeDef",
-        "AnalysisTypes": List[AnalysisTypeType],
+        "Name": NotRequired[str],
+        "CodeReviewArn": NotRequired[str],
+        "RepositoryName": NotRequired[str],
+        "Owner": NotRequired[str],
+        "ProviderType": NotRequired[ProviderTypeType],
+        "State": NotRequired[JobStateType],
+        "StateReason": NotRequired[str],
+        "CreatedTimeStamp": NotRequired[datetime],
+        "LastUpdatedTimeStamp": NotRequired[datetime],
+        "Type": NotRequired[TypeType],
+        "PullRequestId": NotRequired[str],
+        "SourceCodeType": NotRequired["SourceCodeTypeTypeDef"],
+        "AssociationArn": NotRequired[str],
+        "Metrics": NotRequired["MetricsTypeDef"],
+        "AnalysisTypes": NotRequired[List[AnalysisTypeType]],
     },
-    total=False,
 )
 
-_RequiredCodeReviewTypeTypeDef = TypedDict(
-    "_RequiredCodeReviewTypeTypeDef",
+CodeReviewTypeTypeDef = TypedDict(
+    "CodeReviewTypeTypeDef",
     {
         "RepositoryAnalysis": "RepositoryAnalysisTypeDef",
+        "AnalysisTypes": NotRequired[Sequence[AnalysisTypeType]],
     },
 )
-_OptionalCodeReviewTypeTypeDef = TypedDict(
-    "_OptionalCodeReviewTypeTypeDef",
-    {
-        "AnalysisTypes": Sequence[AnalysisTypeType],
-    },
-    total=False,
-)
-
-
-class CodeReviewTypeTypeDef(_RequiredCodeReviewTypeTypeDef, _OptionalCodeReviewTypeTypeDef):
-    pass
-
 
 CommitDiffSourceCodeTypeTypeDef = TypedDict(
     "CommitDiffSourceCodeTypeTypeDef",
     {
-        "SourceCommit": str,
-        "DestinationCommit": str,
-        "MergeBaseCommit": str,
+        "SourceCommit": NotRequired[str],
+        "DestinationCommit": NotRequired[str],
+        "MergeBaseCommit": NotRequired[str],
     },
-    total=False,
 )
 
-_RequiredCreateCodeReviewRequestRequestTypeDef = TypedDict(
-    "_RequiredCreateCodeReviewRequestRequestTypeDef",
+CreateCodeReviewRequestRequestTypeDef = TypedDict(
+    "CreateCodeReviewRequestRequestTypeDef",
     {
         "Name": str,
         "RepositoryAssociationArn": str,
         "Type": "CodeReviewTypeTypeDef",
+        "ClientRequestToken": NotRequired[str],
     },
 )
-_OptionalCreateCodeReviewRequestRequestTypeDef = TypedDict(
-    "_OptionalCreateCodeReviewRequestRequestTypeDef",
-    {
-        "ClientRequestToken": str,
-    },
-    total=False,
-)
-
-
-class CreateCodeReviewRequestRequestTypeDef(
-    _RequiredCreateCodeReviewRequestRequestTypeDef, _OptionalCreateCodeReviewRequestRequestTypeDef
-):
-    pass
-
 
 CreateCodeReviewResponseTypeDef = TypedDict(
     "CreateCodeReviewResponseTypeDef",
@@ -274,28 +224,14 @@ DescribeCodeReviewResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredDescribeRecommendationFeedbackRequestRequestTypeDef = TypedDict(
-    "_RequiredDescribeRecommendationFeedbackRequestRequestTypeDef",
+DescribeRecommendationFeedbackRequestRequestTypeDef = TypedDict(
+    "DescribeRecommendationFeedbackRequestRequestTypeDef",
     {
         "CodeReviewArn": str,
         "RecommendationId": str,
+        "UserId": NotRequired[str],
     },
 )
-_OptionalDescribeRecommendationFeedbackRequestRequestTypeDef = TypedDict(
-    "_OptionalDescribeRecommendationFeedbackRequestRequestTypeDef",
-    {
-        "UserId": str,
-    },
-    total=False,
-)
-
-
-class DescribeRecommendationFeedbackRequestRequestTypeDef(
-    _RequiredDescribeRecommendationFeedbackRequestRequestTypeDef,
-    _OptionalDescribeRecommendationFeedbackRequestRequestTypeDef,
-):
-    pass
-
 
 DescribeRecommendationFeedbackResponseTypeDef = TypedDict(
     "DescribeRecommendationFeedbackResponseTypeDef",
@@ -340,45 +276,30 @@ DisassociateRepositoryResponseTypeDef = TypedDict(
 EventInfoTypeDef = TypedDict(
     "EventInfoTypeDef",
     {
-        "Name": str,
-        "State": str,
+        "Name": NotRequired[str],
+        "State": NotRequired[str],
     },
-    total=False,
 )
 
 KMSKeyDetailsTypeDef = TypedDict(
     "KMSKeyDetailsTypeDef",
     {
-        "KMSKeyId": str,
-        "EncryptionOption": EncryptionOptionType,
+        "KMSKeyId": NotRequired[str],
+        "EncryptionOption": NotRequired[EncryptionOptionType],
     },
-    total=False,
 )
 
-_RequiredListCodeReviewsRequestRequestTypeDef = TypedDict(
-    "_RequiredListCodeReviewsRequestRequestTypeDef",
+ListCodeReviewsRequestRequestTypeDef = TypedDict(
+    "ListCodeReviewsRequestRequestTypeDef",
     {
         "Type": TypeType,
+        "ProviderTypes": NotRequired[Sequence[ProviderTypeType]],
+        "States": NotRequired[Sequence[JobStateType]],
+        "RepositoryNames": NotRequired[Sequence[str]],
+        "MaxResults": NotRequired[int],
+        "NextToken": NotRequired[str],
     },
 )
-_OptionalListCodeReviewsRequestRequestTypeDef = TypedDict(
-    "_OptionalListCodeReviewsRequestRequestTypeDef",
-    {
-        "ProviderTypes": Sequence[ProviderTypeType],
-        "States": Sequence[JobStateType],
-        "RepositoryNames": Sequence[str],
-        "MaxResults": int,
-        "NextToken": str,
-    },
-    total=False,
-)
-
-
-class ListCodeReviewsRequestRequestTypeDef(
-    _RequiredListCodeReviewsRequestRequestTypeDef, _OptionalListCodeReviewsRequestRequestTypeDef
-):
-    pass
-
 
 ListCodeReviewsResponseTypeDef = TypedDict(
     "ListCodeReviewsResponseTypeDef",
@@ -389,30 +310,16 @@ ListCodeReviewsResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredListRecommendationFeedbackRequestRequestTypeDef = TypedDict(
-    "_RequiredListRecommendationFeedbackRequestRequestTypeDef",
+ListRecommendationFeedbackRequestRequestTypeDef = TypedDict(
+    "ListRecommendationFeedbackRequestRequestTypeDef",
     {
         "CodeReviewArn": str,
+        "NextToken": NotRequired[str],
+        "MaxResults": NotRequired[int],
+        "UserIds": NotRequired[Sequence[str]],
+        "RecommendationIds": NotRequired[Sequence[str]],
     },
 )
-_OptionalListRecommendationFeedbackRequestRequestTypeDef = TypedDict(
-    "_OptionalListRecommendationFeedbackRequestRequestTypeDef",
-    {
-        "NextToken": str,
-        "MaxResults": int,
-        "UserIds": Sequence[str],
-        "RecommendationIds": Sequence[str],
-    },
-    total=False,
-)
-
-
-class ListRecommendationFeedbackRequestRequestTypeDef(
-    _RequiredListRecommendationFeedbackRequestRequestTypeDef,
-    _OptionalListRecommendationFeedbackRequestRequestTypeDef,
-):
-    pass
-
 
 ListRecommendationFeedbackResponseTypeDef = TypedDict(
     "ListRecommendationFeedbackResponseTypeDef",
@@ -423,28 +330,14 @@ ListRecommendationFeedbackResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredListRecommendationsRequestRequestTypeDef = TypedDict(
-    "_RequiredListRecommendationsRequestRequestTypeDef",
+ListRecommendationsRequestRequestTypeDef = TypedDict(
+    "ListRecommendationsRequestRequestTypeDef",
     {
         "CodeReviewArn": str,
+        "NextToken": NotRequired[str],
+        "MaxResults": NotRequired[int],
     },
 )
-_OptionalListRecommendationsRequestRequestTypeDef = TypedDict(
-    "_OptionalListRecommendationsRequestRequestTypeDef",
-    {
-        "NextToken": str,
-        "MaxResults": int,
-    },
-    total=False,
-)
-
-
-class ListRecommendationsRequestRequestTypeDef(
-    _RequiredListRecommendationsRequestRequestTypeDef,
-    _OptionalListRecommendationsRequestRequestTypeDef,
-):
-    pass
-
 
 ListRecommendationsResponseTypeDef = TypedDict(
     "ListRecommendationsResponseTypeDef",
@@ -458,14 +351,13 @@ ListRecommendationsResponseTypeDef = TypedDict(
 ListRepositoryAssociationsRequestRequestTypeDef = TypedDict(
     "ListRepositoryAssociationsRequestRequestTypeDef",
     {
-        "ProviderTypes": Sequence[ProviderTypeType],
-        "States": Sequence[RepositoryAssociationStateType],
-        "Names": Sequence[str],
-        "Owners": Sequence[str],
-        "MaxResults": int,
-        "NextToken": str,
+        "ProviderTypes": NotRequired[Sequence[ProviderTypeType]],
+        "States": NotRequired[Sequence[RepositoryAssociationStateType]],
+        "Names": NotRequired[Sequence[str]],
+        "Owners": NotRequired[Sequence[str]],
+        "MaxResults": NotRequired[int],
+        "NextToken": NotRequired[str],
     },
-    total=False,
 )
 
 ListRepositoryAssociationsResponseTypeDef = TypedDict(
@@ -495,29 +387,26 @@ ListTagsForResourceResponseTypeDef = TypedDict(
 MetricsSummaryTypeDef = TypedDict(
     "MetricsSummaryTypeDef",
     {
-        "MeteredLinesOfCodeCount": int,
-        "FindingsCount": int,
+        "MeteredLinesOfCodeCount": NotRequired[int],
+        "FindingsCount": NotRequired[int],
     },
-    total=False,
 )
 
 MetricsTypeDef = TypedDict(
     "MetricsTypeDef",
     {
-        "MeteredLinesOfCodeCount": int,
-        "FindingsCount": int,
+        "MeteredLinesOfCodeCount": NotRequired[int],
+        "FindingsCount": NotRequired[int],
     },
-    total=False,
 )
 
 PaginatorConfigTypeDef = TypedDict(
     "PaginatorConfigTypeDef",
     {
-        "MaxItems": int,
-        "PageSize": int,
-        "StartingToken": str,
+        "MaxItems": NotRequired[int],
+        "PageSize": NotRequired[int],
+        "StartingToken": NotRequired[str],
     },
-    total=False,
 )
 
 PutRecommendationFeedbackRequestRequestTypeDef = TypedDict(
@@ -532,82 +421,76 @@ PutRecommendationFeedbackRequestRequestTypeDef = TypedDict(
 RecommendationFeedbackSummaryTypeDef = TypedDict(
     "RecommendationFeedbackSummaryTypeDef",
     {
-        "RecommendationId": str,
-        "Reactions": List[ReactionType],
-        "UserId": str,
+        "RecommendationId": NotRequired[str],
+        "Reactions": NotRequired[List[ReactionType]],
+        "UserId": NotRequired[str],
     },
-    total=False,
 )
 
 RecommendationFeedbackTypeDef = TypedDict(
     "RecommendationFeedbackTypeDef",
     {
-        "CodeReviewArn": str,
-        "RecommendationId": str,
-        "Reactions": List[ReactionType],
-        "UserId": str,
-        "CreatedTimeStamp": datetime,
-        "LastUpdatedTimeStamp": datetime,
+        "CodeReviewArn": NotRequired[str],
+        "RecommendationId": NotRequired[str],
+        "Reactions": NotRequired[List[ReactionType]],
+        "UserId": NotRequired[str],
+        "CreatedTimeStamp": NotRequired[datetime],
+        "LastUpdatedTimeStamp": NotRequired[datetime],
     },
-    total=False,
 )
 
 RecommendationSummaryTypeDef = TypedDict(
     "RecommendationSummaryTypeDef",
     {
-        "FilePath": str,
-        "RecommendationId": str,
-        "StartLine": int,
-        "EndLine": int,
-        "Description": str,
-        "RecommendationCategory": RecommendationCategoryType,
-        "RuleMetadata": "RuleMetadataTypeDef",
-        "Severity": SeverityType,
+        "FilePath": NotRequired[str],
+        "RecommendationId": NotRequired[str],
+        "StartLine": NotRequired[int],
+        "EndLine": NotRequired[int],
+        "Description": NotRequired[str],
+        "RecommendationCategory": NotRequired[RecommendationCategoryType],
+        "RuleMetadata": NotRequired["RuleMetadataTypeDef"],
+        "Severity": NotRequired[SeverityType],
     },
-    total=False,
 )
 
 RepositoryAnalysisTypeDef = TypedDict(
     "RepositoryAnalysisTypeDef",
     {
-        "RepositoryHead": "RepositoryHeadSourceCodeTypeTypeDef",
-        "SourceCodeType": "SourceCodeTypeTypeDef",
+        "RepositoryHead": NotRequired["RepositoryHeadSourceCodeTypeTypeDef"],
+        "SourceCodeType": NotRequired["SourceCodeTypeTypeDef"],
     },
-    total=False,
 )
 
 RepositoryAssociationSummaryTypeDef = TypedDict(
     "RepositoryAssociationSummaryTypeDef",
     {
-        "AssociationArn": str,
-        "ConnectionArn": str,
-        "LastUpdatedTimeStamp": datetime,
-        "AssociationId": str,
-        "Name": str,
-        "Owner": str,
-        "ProviderType": ProviderTypeType,
-        "State": RepositoryAssociationStateType,
+        "AssociationArn": NotRequired[str],
+        "ConnectionArn": NotRequired[str],
+        "LastUpdatedTimeStamp": NotRequired[datetime],
+        "AssociationId": NotRequired[str],
+        "Name": NotRequired[str],
+        "Owner": NotRequired[str],
+        "ProviderType": NotRequired[ProviderTypeType],
+        "State": NotRequired[RepositoryAssociationStateType],
     },
-    total=False,
 )
 
 RepositoryAssociationTypeDef = TypedDict(
     "RepositoryAssociationTypeDef",
     {
-        "AssociationId": str,
-        "AssociationArn": str,
-        "ConnectionArn": str,
-        "Name": str,
-        "Owner": str,
-        "ProviderType": ProviderTypeType,
-        "State": RepositoryAssociationStateType,
-        "StateReason": str,
-        "LastUpdatedTimeStamp": datetime,
-        "CreatedTimeStamp": datetime,
-        "KMSKeyDetails": "KMSKeyDetailsTypeDef",
-        "S3RepositoryDetails": "S3RepositoryDetailsTypeDef",
+        "AssociationId": NotRequired[str],
+        "AssociationArn": NotRequired[str],
+        "ConnectionArn": NotRequired[str],
+        "Name": NotRequired[str],
+        "Owner": NotRequired[str],
+        "ProviderType": NotRequired[ProviderTypeType],
+        "State": NotRequired[RepositoryAssociationStateType],
+        "StateReason": NotRequired[str],
+        "LastUpdatedTimeStamp": NotRequired[datetime],
+        "CreatedTimeStamp": NotRequired[datetime],
+        "KMSKeyDetails": NotRequired["KMSKeyDetailsTypeDef"],
+        "S3RepositoryDetails": NotRequired["S3RepositoryDetailsTypeDef"],
     },
-    total=False,
 )
 
 RepositoryHeadSourceCodeTypeTypeDef = TypedDict(
@@ -620,23 +503,21 @@ RepositoryHeadSourceCodeTypeTypeDef = TypedDict(
 RepositoryTypeDef = TypedDict(
     "RepositoryTypeDef",
     {
-        "CodeCommit": "CodeCommitRepositoryTypeDef",
-        "Bitbucket": "ThirdPartySourceRepositoryTypeDef",
-        "GitHubEnterpriseServer": "ThirdPartySourceRepositoryTypeDef",
-        "S3Bucket": "S3RepositoryTypeDef",
+        "CodeCommit": NotRequired["CodeCommitRepositoryTypeDef"],
+        "Bitbucket": NotRequired["ThirdPartySourceRepositoryTypeDef"],
+        "GitHubEnterpriseServer": NotRequired["ThirdPartySourceRepositoryTypeDef"],
+        "S3Bucket": NotRequired["S3RepositoryTypeDef"],
     },
-    total=False,
 )
 
 RequestMetadataTypeDef = TypedDict(
     "RequestMetadataTypeDef",
     {
-        "RequestId": str,
-        "Requester": str,
-        "EventInfo": "EventInfoTypeDef",
-        "VendorName": VendorNameType,
+        "RequestId": NotRequired[str],
+        "Requester": NotRequired[str],
+        "EventInfo": NotRequired["EventInfoTypeDef"],
+        "VendorName": NotRequired[VendorNameType],
     },
-    total=False,
 )
 
 ResponseMetadataTypeDef = TypedDict(
@@ -653,43 +534,28 @@ ResponseMetadataTypeDef = TypedDict(
 RuleMetadataTypeDef = TypedDict(
     "RuleMetadataTypeDef",
     {
-        "RuleId": str,
-        "RuleName": str,
-        "ShortDescription": str,
-        "LongDescription": str,
-        "RuleTags": List[str],
+        "RuleId": NotRequired[str],
+        "RuleName": NotRequired[str],
+        "ShortDescription": NotRequired[str],
+        "LongDescription": NotRequired[str],
+        "RuleTags": NotRequired[List[str]],
     },
-    total=False,
 )
 
-_RequiredS3BucketRepositoryTypeDef = TypedDict(
-    "_RequiredS3BucketRepositoryTypeDef",
+S3BucketRepositoryTypeDef = TypedDict(
+    "S3BucketRepositoryTypeDef",
     {
         "Name": str,
+        "Details": NotRequired["S3RepositoryDetailsTypeDef"],
     },
 )
-_OptionalS3BucketRepositoryTypeDef = TypedDict(
-    "_OptionalS3BucketRepositoryTypeDef",
-    {
-        "Details": "S3RepositoryDetailsTypeDef",
-    },
-    total=False,
-)
-
-
-class S3BucketRepositoryTypeDef(
-    _RequiredS3BucketRepositoryTypeDef, _OptionalS3BucketRepositoryTypeDef
-):
-    pass
-
 
 S3RepositoryDetailsTypeDef = TypedDict(
     "S3RepositoryDetailsTypeDef",
     {
-        "BucketName": str,
-        "CodeArtifacts": "CodeArtifactsTypeDef",
+        "BucketName": NotRequired[str],
+        "CodeArtifacts": NotRequired["CodeArtifactsTypeDef"],
     },
-    total=False,
 )
 
 S3RepositoryTypeDef = TypedDict(
@@ -703,13 +569,12 @@ S3RepositoryTypeDef = TypedDict(
 SourceCodeTypeTypeDef = TypedDict(
     "SourceCodeTypeTypeDef",
     {
-        "CommitDiff": "CommitDiffSourceCodeTypeTypeDef",
-        "RepositoryHead": "RepositoryHeadSourceCodeTypeTypeDef",
-        "BranchDiff": "BranchDiffSourceCodeTypeTypeDef",
-        "S3BucketRepository": "S3BucketRepositoryTypeDef",
-        "RequestMetadata": "RequestMetadataTypeDef",
+        "CommitDiff": NotRequired["CommitDiffSourceCodeTypeTypeDef"],
+        "RepositoryHead": NotRequired["RepositoryHeadSourceCodeTypeTypeDef"],
+        "BranchDiff": NotRequired["BranchDiffSourceCodeTypeTypeDef"],
+        "S3BucketRepository": NotRequired["S3BucketRepositoryTypeDef"],
+        "RequestMetadata": NotRequired["RequestMetadataTypeDef"],
     },
-    total=False,
 )
 
 TagResourceRequestRequestTypeDef = TypedDict(
@@ -740,8 +605,7 @@ UntagResourceRequestRequestTypeDef = TypedDict(
 WaiterConfigTypeDef = TypedDict(
     "WaiterConfigTypeDef",
     {
-        "Delay": int,
-        "MaxAttempts": int,
+        "Delay": NotRequired[int],
+        "MaxAttempts": NotRequired[int],
     },
-    total=False,
 )
